==> nextcloud-23.0.8.tgz: nextcloud/apps/twofactor_backupcodes/l10n/sr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Направили сте двофакторске резервне кодове за Ваш налог",
    "Second-factor backup codes" : "Двофакторски резервни кодови",
    "Generate backup codes" : "Генериши резервне кодове",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Укључили сте двофакторску проверу идентитета, али још нисте генерисали резервне кодове. Они су потребни да вратите приступ Вашем налогу, у случају да изгубите приступ Вашем другом фактору.",
    "Backup code" : "Резервни код",
    "Use backup code" : "Искористи резервни код",
    "Two factor backup codes" : "Двофакторски резервни кодови",
    "A two-factor auth backup codes provider" : "Провајдер резервних кодова за двофакторску ауторизацију",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервни кодови су изгенерисани. {used} од {total} кодова је искоришћено.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ово су Ваши резервни кодови. Сачувајте их и/или их одштампајте пошто више нећете моћи да их прочитате.",
    "Save backup codes" : "Сачувај резервне кодове",
    "Print backup codes" : "Одштампај резервне кодове",
    "Regenerate backup codes" : "Поново генериши резервне кодове",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ако поново генеришете резервне кодове, стари аутоматски престају да важе.",
    "An error occurred while generating your backup codes" : "Десила се грешка приликом генерисања резервних кодова",
    "{name} backup codes" : "{name} резервни кодови",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Искористите један од резервних кодова које сте сачували када се подешавали двофакторску проверу идентитета.",
    "Submit" : "Пошаљи"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/twofactor_backupcodes/l10n/sr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Направили сте двофакторске резервне кодове за Ваш налог",
    "Second-factor backup codes" : "Двофакторски резервни кодови",
    "Generate backup codes" : "Генериши резервне кодове",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Укључили сте двофакторску проверу идентитета, али још нисте генерисали резервне кодове. Они су потребни да вратите приступ Вашем налогу, у случају да изгубите приступ Вашем другом фактору.",
    "Backup code" : "Резервни код",
    "Use backup code" : "Искористи резервни код",
    "Two factor backup codes" : "Двофакторски резервни кодови",
    "A two-factor auth backup codes provider" : "Провајдер резервних кодова за двофакторску ауторизацију",
    "An error occurred while generating your backup codes" : "Десила се грешка приликом генерисања резервних кодова",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервни кодови су изгенерисани. {used} од {total} кодова је искоришћено.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later." : "Ово су ваши резервни кодови. Сачувајте их и/или их одштампајте пошто више нећете моћи поново да их прочитате.",
    "Save backup codes" : "Сачувај резервне кодове",
    "Print backup codes" : "Одштампај резервне кодове",
    "Regenerate backup codes" : "Поново генериши резервне кодове",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ако поново генеришете резервне кодове, стари аутоматски престају да важе.",
    "{name} backup codes" : "{name} резервни кодови",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Искористите један од резервних кодова које сте сачували када се подешавали двофакторску проверу идентитета.",
    "Submit" : "Пошаљи"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
